| Date | Version | Comment |
| ------------- | ------------- | ------------- |
| 2021/05/08 | 0.9.8 | Adding data type in Quote file.|
| 2021/04/27 | 0.9.7 | Update Value Error message https://github.com/lit26/finvizfinance/issues/23. Adding insider options https://github.com/lit26/finvizfinance/pull/22 |
| 2021/04/18 | 0.9.6 | Increase performance and add timeout https://github.com/lit26/finvizfinance/issues/21.|
| 2021/04/14 | 0.9.5 | Add quarterly statements https://github.com/lit26/finvizfinance/issues/19.|
| 2021/04/13 | 0.9.4 | Fix bug for weekly chart https://github.com/lit26/finvizfinance/issues/18.|
| 2021/03/06 | 0.9.3 | Add ticker statements |
| 2021/02/23 | 0.9.2 | Fix bug for PyPi packages |
| 2021/02/23 | 0.9 | Changing screener structure. Adding Custom screener https://github.com/lit26/finvizfinance/issues/12.|
| 2021/02/15 | 0.8.2 | Fix error type https://github.com/lit26/finvizfinance/issues/10|
| 2021/02/07 | 0.8.1 | Fix bug in screener order |
| 2021/02/05 | 0.8 | Adding ascend and descend to screener and fixing code style |
| 2021/01/11 | 0.7.5 | Add current price function |
| 2021/01/04 | 0.7.4 | Update progress bar |
| 2020/12/29 | 0.7.3 | Adding stock trading signals in quote, fixing bug in stock fundamental |
| 2020/11/24 | 0.7.2 | Adding optional download for charts |
| 2020/10/01 | 0.7.1 | Adding future module |
| 2020/09/19 | 0.7 | Adding top K rows in the screener dataframe and update request error |
| 2020/08/21 | 0.6.2 | Update printing |
| 2020/08/17 | 0.6.1 | Fix PyPi package error |
| 2020/08/17 | 0.6 | Add earning module |
| 2020/08/15 | 0.5.1 | Fix bug in group folder |
| 2020/08/15 | 0.5 | Update Quote module and add compare function to screener |
| 2020/08/14 | 0.4.1 | Add group spectrum module |
| 2020/08/14 | 0.4 | Add group folder |
| 2020/08/13 | 0.3 | Add forex and crypto module |
| 2020/08/02 | 0.2.3 | Update filter in screener |
| 2020/08/02 | 0.2.2 | Fix a bug in screen order|
| 2020/07/31 | 0.2.1 | Add order to screen module |
| 2020/07/31 | 0.2 | Fix a bug |
